Changelog
=========


0.2.0 (2018-04-25)
------------------

- Add instructions to README.md on how to do a release.


0.1.0 (2018-04-25)
------------------

- Add the minimal requirements to publish flit package on pypi.org.
